@@ -27,8 +27,8 @@ HTDOCS_PREFIX = 'mobyle/xxxxx'
 #a list of email addresses who will received messages when problems occur
 MAINTAINER = [ "name@mydommain.fr" ]
 
-#the email address where the users could have help on this Mobyle portal
-HELP="name2@mydommain.fr"
+#a list of email addresses where the users could have help on this Mobyle portal
+HELP= [ "name2@mydommain.fr" , "name3@mydommain.fr" ]
 
 # local mailhost
 MAILHOST= "mailhost.mydommain.fr"
