@@ -58,7 +58,7 @@ class Config( object ):
     __metaclass__ = MetaSingleton
     
     def __init__(self):
-            self.__version = '1.0.6'
+            self.__version = '1.0.7'
             import Local.Config.Config
             import Local.Config.Execution
             #############################
@@ -331,9 +331,9 @@ class Config( object ):
                     self._maintainer = [ Local.Config.Config.MAINTAINER ]
                     
                 if type( Local.Config.Config.HELP ) == types.ListType or type( Local.Config.Config.HELP ) == types.TupleType :    
-                    self._help = " , ".join( Local.Config.Config.HELP )
-                else:
                     self._help = Local.Config.Config.HELP
+                else:
+                    self._help = [ Local.Config.Config.HELP ]
 
                 self._mailhost = Local.Config.Config.MAILHOST
             except AttributeError, err:
@@ -344,7 +344,7 @@ class Config( object ):
             try:
                 self._sender = Local.Config.Config.SENDER
             except AttributeError, err:
-                self._sender = self._help
+                self._sender = ", ".join( self._help )
                 self.log.info( "SENDER not found in  Local/Config/Config.py , set SENDER to HELP ")
                 
             try:
@@ -886,14 +886,14 @@ class Config( object ):
     def maintainer( self ):
         """
         @return: the email address of the Mobyle server  maintainer
-        @rtype: string
+        @rtype: list of string
         """
         return self._maintainer
 
     def mailHelp( self ):
         """
         @return: The email address to the hot line for this Mobyle server
-        @rtype: string
+        @rtype: list of string
         """
         return self._help
     
