@@ -367,7 +367,7 @@ class Registry(DefNode):
         """
         @param url: the url of 
         @type url: string
-        @return: the potal identifier for this (the portal id is)
+        @return: the portal identifier for this job
         @rtype: string
         """
         server = self.getServerByJobId(url)
@@ -376,6 +376,15 @@ class Registry(DefNode):
             jobPID = server.name + '.' + jobPID
         return jobPID
 
+    def isJobLocal(self, url):
+        """
+        @param url: the url of 
+        @type url: string
+        @return: true if the job is local, false otherwise
+        @rtype: boolean
+        """
+        return self.getJobPID(url).find('.')>-1 or self.getJobPID(url).startswith('local.')
+
     def getJobURL(self, pid):
         # if the PID is composite (i.e. it's a workflow task), only take the last part into account. 
         pid = pid.split('::').pop() 
