@@ -202,7 +202,7 @@ def killJob( jobID ):
         if js.isWorkflow():
             job = WorkflowJob( id= jobID )
         else:
-            job= Job( ID= jobID )
+            job= Job(ID = jobID)
         try:
             job.kill()
         except MobyleError , err :
@@ -212,10 +212,9 @@ def killJob( jobID ):
         msg = ''
         for jobID , msgErr in errors :
             msg = "%s killJob( %s ) - %s\n" % ( msg , jobID , msgErr )
-            
         raise MobyleError , msg
 
-def safeFileName( fileName ):
+def safeFileName(fileName):
     import string , re
     
     if fileName in ( 'index.xml' , '.admin' , '.command' ,'.forChild.dump' ,'.session.xml'):
@@ -223,8 +222,11 @@ def safeFileName( fileName ):
     
     for car in fileName :
         if car not in string.printable : #we don't allow  non ascii char
-            fileName = fileName.replace( car , '_')
-    
+            try:
+                fileName = fileName.replace( car , '_')
+            except Exception, err:
+                u_log.error( "error in safeFileName: %s \ncall with fileName= %s"%fileName, exc_info= True)
+                raise MobyleError( "Internal Mobyle Server Error")
     #SECURITY: substitution of shell special characters
     fileName = re.sub( "[ ~%#\"\'<>&\*;$`\|()\[\]\{\}\?\s ]" , '_' , fileName )
                   
@@ -337,7 +339,7 @@ def emailResults( cfg , userEmail, registry, ID, job_path, serviceName, jobKey,
             if FileName is not None:
                 zipSize = os.path.getsize( FileName )
                 mailDict = { 'SENDER'         : cfg.sender() ,
-                             'HELP'           : cfg.mailHelp() ,
+                             'HELP'           : ", ".join( cfg.mailHelp() ) ,
                              'SERVER_NAME'    : cfg.portal_url() ,
                              'JOB_URL'        : jobInPortalUrl , 
                              'RESULTS_REMAIN' : cfg.remainResults() ,
